#!/bin/bash

#Cine Digital Manager

############################################################ Partie INSTALLATION ############################################################################################
# Liste des logiciels à installer
# ffmpeg
# OpenJpeg
# Asdcplib
# opencinematools
# sox

#Variable
#Super User DO
INSTALL="apt-get --yes install"
REPERTOIRE="apt-add-repository"
MAJ="apt-get update" 

function initialisation {
	cd /tmp
	mkdir conversionDCPCDS
}

function clean {
	cd /tmp
	rm -r conversionDCPCDS
 }

function install_openjpeg {
	sudo $INSTALL openjpeg-tools && echo "Installation OpenJpeg Terminée"
}

function install_sox {
	sudo $INSTALL sox && echo "Installation Sox Terminée"
}

function install_git {
	sudo $INSTALL git-core && echo "Installation Git Terminée"
}

function install_imagemagick {
	sudo $INSTALL imagemagick && echo "Installation imagemagick Terminée"
}

function install_yasm {
	sudo $INSTALL yasm && echo "Installation Yasm Terminée"
}

function install_libraries {
	sudo $INSTALL libxslt1.1 libxslt1-dev openssl libssl-dev libxml2 libxmlsec1 xmlsec1 libxmlsec1-dev libxmlsec1-openssl libtiff4 libtiff4-dev libopenjpeg2  libopenjpeg-dev  libexpat1-dev  libxml2-dev g++ libtool build-essential libxerces-c-dev && echo "Installation des librairies terminée"
}

function install_ffmpeg {
	install_git
	install_yasm
	wget "update.cinedigitalservice.com/ffmpeg.tar.bz2"
	tar xjvf ffmpeg.tar.bz2
	cd ffmpeg
	sudo ./configure
	sudo make install
	echo "Installation ffmpeg Terminée"
}

#Normalement inutile, asdcplib est installé par opencinematools
function install_asdcplib {
	install_libraries
	wget www.cinecert.com/asdcplib/asdcplib-1.8.44.tar.gz && echo "telechargement terminé"
	tar xvzf asdcplib-1.8.44.tar.gz
	cd asdcplib-1.8.44/
	sudo ./configure
	sudo make install

	sudo cp /usr/local/lib/libasdcp-1.8.44.so /lib/
	sudo cp /usr/local/lib/libkumu-1.8.44.so /lib/
}


function install_opencinematools {
	sudo $REPERTOIRE "deb http://update.cinedigitalservice.com lucid stable"
	#On supprime le deb-src ajouté par apt-add-repository et qui n'existe pas
	sed -i -e 's#deb-src http://update.cinedigitalservice.com lucid stable##' /etc/apt/sources.list
	#On telecharge la clef
	wget http://update.cinedigitalservice.com/dists/lucid/CDS.gpg
	sudo apt-key add CDS.gpg
	sudo $MAJ
	sudo $INSTALL opencinematools
}

function install_default {
	install_opencinematools
	install_ffmpeg
	install_openjpeg
	install_imagemagick
	install_sox
#	install_asdcplib
}	

if [[ $# == 0 ]]
then
	echo "Installation par défaut"
	install_default
elif [[ $# == 1 ]]
then
	if [[ $1 == "--help" ]]
	then
		echo -e "Bienvenue dans l'aide \\n"
		echo -e "\t all (option par defaut) : installe tout les logiciels suivant: \n"
		echo -e "\t \t ffmpeg \n \t \t openjpeg \n \t \t asdcplib \n \t \t git \n \t \t opencinematools \n "
		echo -e "\t Pour installer un seul logiciel mettez le en argument \n \t \t $0 nomdulogiciel "
	elif [[ $1 == "openjpeg" ]] || [[ $1 == "opencinematools" ]] || [[ $1 == "git" ]] || [[ $1 == "asdcplib" ]] || [[ $1 == "ffmpeg" ]] || [[ $1 == "imagemagick" ]]
	then
		echo "Installation de $1"
		install_$1
	elif [[ $1 == "all" ]]
	then
		echo "Installation par défaut"
		install_default
	fi
elif [[ $# > 1 ]]
then
	echo -e " Commande inconnue \n \t taper \"$0 --help\" pour plus d'informations"
fi	



